package ExtUtils::Builder::AutoDetect::C;
$ExtUtils::Builder::AutoDetect::C::VERSION = '0.034';
use parent 'ExtUtils::Builder::BuildTools::FromPerl';

1;

# ABSTRACT: Backwards compatability shim for ExtUtils::Builder::BuildTools::FromPerl

__END__

=pod

=encoding UTF-8

=head1 NAME

ExtUtils::Builder::AutoDetect::C - Backwards compatability shim for ExtUtils::Builder::BuildTools::FromPerl

=head1 VERSION

version 0.034

=head1 DESCRIPTION

This is a backwards compatability shim for L<ExtUtils::Builder::BuildTools::FromPerl>, you should use that instead.

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
